@@ -108,18 +108,7 @@ package Term::Size::Perl::Params;
 # created @{[scalar localtime]}
 
 use vars qw(\$VERSION);
-\$VERSION = @{[MM->parse_version('Perl.pm')]};
-
-\=head1 Term::Size::Perl::Params
-
-\=head2 params
-
-    \$href = Term::Size::Perl::Params
-
-The configuration parameters C<Term::Size::Perl> needs to
-know for retrieving the terminal size with C<ioctl>.
-
-\=cut
+\$VERSION = '@{[MM->parse_version('Perl.pm')]}';
 
 sub params {
     return (
@@ -136,6 +125,31 @@ sub params {
 
 1;
 
+\=pod
+
+\=head1 NAME
+
+Term::Size::Perl::Params - Configuration for Term::Size::Perl
+
+\=head1 SYNOPSIS
+
+    use Term::Size::Perl::Params ();
+
+    %%%%params = Term::Size::Perl::Params::params();
+
+\=head1 DESCRIPTION
+
+The configuration parameters C<Term::Size::Perl> needs to
+know for retrieving the terminal size with C<ioctl>.
+
+\=head1 FUNCTIONS
+
+\=head2 params
+
+The configuration parameters C<Term::Size::Perl> needs to
+know for retrieving the terminal size with C<ioctl>.
+
+\=cut
 
 PARAMS
 
@@ -153,10 +167,6 @@ my $PROBE_TEMPLATE = sprintf <<PROBE;
  * configuration to make it possible using 
  * ioctl(., TIOCGWINSZ, .) to
  * get the terminal size via pure Perl code. 
- *
- *
- *
- *
  */
 
 #include <stdio.h>
